package com.fr.plugin.widget;


import com.fr.form.ui.FieldEditor;
import com.fr.form.ui.TextEditor;
import com.fr.form.ui.WidgetXmlUtils;
import com.fr.form.ui.reg.RegExp;
import com.fr.general.ComparatorUtils;
import com.fr.general.xml.GeneralXMLTools;
import com.fr.json.JSONException;
import com.fr.json.JSONObject;
import com.fr.plugin.MyFunctionConstants;
import com.fr.script.Calculator;
import com.fr.stable.StringUtils;
import com.fr.stable.core.NodeVisitor;
import com.fr.stable.web.Repository;
import com.fr.stable.xml.XMLPrintWriter;
import com.fr.stable.xml.XMLableReader;

public class MyEditorWidget extends TextEditor {
    private String cf1 ;
    private boolean cf2 = true;
    private String cf3 ;
    private RegExp regex;
    protected String errorMessage;
    @Override
    public String getXType() {
      return   MyFunctionConstants.WIDGET_NAME;
    }
    @Override
    public JSONObject createJSONConfig(Repository repository, Calculator calculator, NodeVisitor nodeVisitor) throws JSONException {
        JSONObject jsonObject = super.createJSONConfig(repository, calculator, nodeVisitor);
//        jsonObject.put("cf1", this.cf1);
        if (StringUtils.isNotBlank(this.errorMessage)) {
            jsonObject.put("errorMsg", this.errorMessage);
        }
        jsonObject.put("render", true);
        if (this.regex != null) {
            jsonObject.put("regex", this.getRegex().toRegText());
        }
        if (StringUtils.isNotBlank(this.cf1)) {
            FieldEditor.setWaterMarkConfig(this.cf1, jsonObject, calculator);
            jsonObject.put("cf1", this.cf1);
        }

       jsonObject.put("cf2", this.cf2);

        if (StringUtils.isNotBlank(this.cf3)) {

            jsonObject.put("cf3", this.cf3);
        }else {
            jsonObject.put("cf3", "");
        }

        return jsonObject;
    }
    @Override
    public void readXML(XMLableReader xmLableReader) {
        super.readXML(xmLableReader);
        if (xmLableReader.isChildNode()) {
            String tagName = xmLableReader.getTagName();
            if (tagName.equals("Reg")) {
                this.regex = WidgetXmlUtils.readXMLReg(xmLableReader);
            }
            if (xmLableReader.getTagName().equals("EMSG")) {
                this.errorMessage = xmLableReader.getElementValue();
            }

            if("cf1".equals(tagName)){

                this.setCf1(xmLableReader.getElementValue());
            }
            if("cf2".equals(tagName)){

                this.cf2 = false;;
            }
            if("cf3".equals(tagName)){

                this.setCf3(xmLableReader.getElementValue());
            }
//            if(ComparatorUtils.equals(tagName,"cf1")){
//
//                this.cf1 = xmLableReader.getAttrAsString("cf1","");
//            }
//            if(ComparatorUtils.equals(tagName,"cf2")){
//
//                this.cf2 = xmLableReader.getAttrAsString("cf2","");
//            }
//            if(ComparatorUtils.equals(tagName,"cf3")){
//
//                this.cf3 = xmLableReader.getAttrAsString("cf3","");
//            }
        }
    }
    @Override
    public void writeXML(XMLPrintWriter xmlPrintWriter) {
        super.writeXML(xmlPrintWriter);
//        xmlPrintWriter.startTAG("cf1").textNode(cf1).end();
//        xmlPrintWriter.startTAG("cf2").textNode(cf2).end();
//        xmlPrintWriter.startTAG("cf3").textNode(cf3).end();

        if (StringUtils.isNotBlank(this.cf1)) {
            xmlPrintWriter.startTAG("cf1").textNode(this.cf1).end();
        }

        if (!this.isCf2()) {
            xmlPrintWriter.startTAG("cf2").textNode(String.valueOf(this.cf2)).end();
        }

        if (StringUtils.isNotBlank(this.cf3)) {
            xmlPrintWriter.startTAG("cf3").textNode(this.cf3).end();
        }
        if (this.regex != null) {
            GeneralXMLTools.writeXMLable(xmlPrintWriter, this.regex, "Reg");
        }
        if (StringUtils.isNotBlank(this.errorMessage)) {
            xmlPrintWriter.startTAG("EMSG").textNode(this.errorMessage).end();
        }
    }
    @Override
    public boolean isEditor(){
        return  true;
    }
    public String getCf1() {
        return cf1;
    }

    public void setCf1(String cf1) {
        this.cf1 = cf1;
    }


    public String getCf3() {
        return cf3;
    }

    public void setCf3(String cf3) {
        this.cf3 = cf3;
    }

    public boolean isCf2() {
        return cf2;
    }

    public void setCf2(boolean cf2) {
        this.cf2 = cf2;
    }
    @Override
    public RegExp getRegex() {
        return regex;
    }

    @Override
    public void setRegex(RegExp regex) {
        this.regex = regex;
    }
    @Override
    public String getErrorMessage() {
        return errorMessage;
    }

    @Override
    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }


}
